[![pypi](https://img.shields.io/pypi/v/lnschema_core?color=%2334D058&label=pypi%20package)](https://pypi.org/project/lnschema_core)

# lnschema-core: Data objects & data lineage (`yvzi`)

- Stable user docs: [lamin.ai/docs/reference/](https://lamin.ai/docs/reference/)
- Latest developer docs: [netlify](https://lnschema-core-yvzi.netlify.app/docs/lnschema-core/)
